@@ -9,6 +9,9 @@ Mojolicious::Plugin::Swagger2 - Mojolicious plugin for Swagger2
 L<Mojolicious::Plugin::Swagger2> is L<Mojolicious::Plugin> that add routes and
 input/output validation to your L<Mojolicious> application.
 
+Please read L<http://thorsen.pm/perl/programming/2015/07/05/mojolicious-swagger2.html>
+for an introduction to this plugin and reasons for why you would to use it.
+
 Have a look at this L<example blog app|https://github.com/jhthorsen/swagger2/tree/master/t/blog>
 too see a complete working example, with a database backend. Questions and
 comments on how to improve the example are very much welcome.
@@ -150,6 +153,18 @@ L</Swagger specification>, C<MyApp::authenticate_api_request>:
 
 This feature is EXPERIMENTAL and can change without notice.
 
+=head2 Stash variables
+
+=head3 swagger
+
+The L<Swagger2> object used to generate the routes is available
+as C<swagger> from L<stash|Mojolicious/stash>. Example code:
+
+  sub documentation {
+    my ($c, $args, $cb);
+    $c->$cb($c->stash('swagger')->pod->to_string, 200);
+  }
+
 =cut
 
 use Mojo::Base 'Mojolicious::Plugin';
@@ -302,8 +317,15 @@ sub register {
   $app->helper(render_swagger => \&render_swagger) unless $app->renderer->get_helper('render_swagger');
 
   $r = $config->{route};
-  $r = $r->any($swagger->base_url->path->to_string) if $r and !$r->pattern->unparsed;
-  $r = $app->routes->any($swagger->base_url->path->to_string) unless $r;
+
+  if ($r and !$r->pattern->unparsed) {
+    $r->to(swagger => $swagger);
+    $r = $r->any($swagger->base_url->path->to_string);
+  }
+  if (!$r) {
+    $r = $app->routes->any($swagger->base_url->path->to_string);
+    $r->to(swagger => $swagger);
+  }
 
   for my $path (keys %$paths) {
     for my $http_method (keys %{$paths->{$path}}) {
@@ -453,7 +475,7 @@ sub _die {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014, Jan Henning Thorsen
+Copyright (C) 2014-2015, Jan Henning Thorsen
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
