@@ -6,7 +6,7 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.46
+0.47
 
 =head1 DESCRIPTION
 
@@ -15,6 +15,9 @@ L<swagger|http://swagger.io/> API documentation. It has support for reading
 swagger specification in JSON notation and it can also read YAML files,
 if a L</YAML parser> is installed.
 
+Please read L<http://thorsen.pm/perl/programming/2015/07/05/mojolicious-swagger2.html>
+for an introduction to Swagger and reasons for why you would to use it.
+
 =head2 Mojolicious server side code generator
 
 This distribution comes with a L<Mojolicious> plugin,
@@ -63,7 +66,7 @@ use constant CACHE_DIR => $ENV{SWAGGER2_CACHE_DIR}
 
 use constant DEBUG => $ENV{SWAGGER2_DEBUG} || 0;
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 
 # Should be considered internal
 our @SPEC_FILE = (File::Spec->splitdir(File::Basename::dirname(__FILE__)), 'Swagger2', 'schema.json');
@@ -399,7 +402,7 @@ sub _parse {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014, Jan Henning Thorsen
+Copyright (C) 2014-2015, Jan Henning Thorsen
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
